function M=loadSPE(filename,num_rows,num_columns)
% M=loadSPE(filename,num_rows,num_columns)
%
% The function loads SPE file "filename" to Matlab.
% It creats a three-dimensional variable M, which j-th matrix is j-th frame of the file "filename".
% Positions in matrix are the same as pixels in original pictures.
% i. e. M(1,1,j) is left top corner of j-th picture, 
% M(256,1024,j) is right bottom corner (if the picture has all 1024*256 pixels on camera).
% If you define variables "num_rows" and "num_columns" (vectors with two elements),
% it reads only the rows between num_rows(1) and num_rows(2) 
% and columns between num_columns(1) and num_columns(2).

fid=fopen(filename,'r');
header=fread(fid,2050,'uint16'); %hlavicka, 4100bytes/2

nsloupcu=header(22);
nradku=header(329);
n=header(724);
acc=header(57);

switch nargin
 case 1
  num_rows=[1 nradku];
  num_columns=[1 nsloupcu];
 case 2
  num_columns=[1 nsloupcu];
end
if length(num_columns)==0
 num_columns=[1 nsloupcu];
end
if length(num_rows)==0
 num_rows=[1 nradku];
end

for j=1:n, 
 M1=fread(fid,nsloupcu*nradku,'uint16');
 M1=reshape(M1,nsloupcu,nradku);
 M1=double(M1);
 M1=rot90(M1);
 M1=flipud(M1); 
 M1=M1(num_rows(1):num_rows(2),num_columns(1):num_columns(2));
 M(:,:,j)=M1;
end
fclose(fid);

%figure; graphSPE(M(:,:,round(n/2))); %vygrafeni prostredniho obrazku
